==> musashi-core-1.0.3.tar.gz: musashi-core-1.0.3/lib/include/musashi/mssPMML.h <==
/**
 * # CHAPTER #
 * ============================================================================
 * PMMLϢΥإåե
 * ============================================================================
 */

#ifndef __MSSPMML_H
#define __MSSPMML_H 1

/**
 * # STRUCT #
 * MUSASHIPMMLϻѤ륰Хѿ¤(mssPMML.cˤ)
 */
struct mssPMMLvariables {
  int indentLevel; /*ߤΥǥȤΥ٥*/
  int outRetCnt; /*ϤԿ*/
};

/**
 * # PROTOTYPE # 
 */
void mssPMMLinit(void);
void mssPMMLindent(struct mssFPW *fpw);

void mssPMMLextensionStart( char *extender, char *name, char *value, int   emptyFlg, struct mssFPW *fpw);
void mssPMMLextensionEnd(struct mssFPW *fpw);
void mssPMMLarrayStr(int *n, char **str, struct mssFPW *fpw);
void mssPMMLfalseEmpty(struct mssFPW *fpw);
void mssPMMLtrueEmpty(struct mssFPW *fpw);

void mssPMMLpmmlStart( char *version, struct mssFPW *fpw);
void mssPMMLpmmlEnd(struct mssFPW *fpw);

void mssPMMLheaderStart(char *copyright, char *description, struct mssFPW *fpw);
void mssPMMLheaderEnd(struct mssFPW *fpw);
void mssPMMLapplicationEmpty( char *name, char *version, struct mssFPW *fpw);
void mssPMMLtimestamp(struct mssFPW *fpw);

void mssPMMLdataDictionaryStart( int *numberOfFields, struct mssFPW *fpw);
void mssPMMLdataDictionaryEnd(struct mssFPW *fpw);
void mssPMMLdataFieldStart(char *name, char *displayName, char *optype, char *taxonomy, int  *isCyclic, int emptyFlg, struct mssFPW *fpw);
void mssPMMLdataFieldEnd(struct mssFPW *fpw);
void mssPMMLvalueStart( char *value, char *displayValue, char *property, int emptyFlg, struct mssFPW *fpw);
void mssPMMLvalueEnd(struct mssFPW *fpw);


void mssPMMLminingSchemaStart(struct mssFPW *fpw);
void mssPMMLminingSchemaEnd(struct mssFPW *fpw);
void mssPMMLminingFieldStart(char *name, char *usageType, char *outliers, double *lowValue, double *highValue, char *missingValueReplacement, char *missingValueTreatment, int emptyFlg, struct mssFPW *fpw);
void mssPMMLminingFieldEnd(struct mssFPW *fpw);
void mssPMMLminingFields( struct mssFields *fld, char *usageType, char *outliers, double *lowValue, double *highValue, char *missingValueReplacement, char *missingValueTreatment, struct mssFPW *fpw);
void mssPMMLtreeModelStart( char *modelName, char *functionName, char *algorithmName, char *splitCharacteristic, struct mssFPW *fpw);
void mssPMMLtreeModelEnd(struct mssFPW *fpw);
void mssPMMLnodeStart( char *score, double *recordCount, struct mssFPW *fpw);
void mssPMMLnodeEnd(struct mssFPW *fpw);
void mssPMMLsimplePredicateNumEmpty(char *field,char *operator, double *value, struct mssFPW *fpw);
void mssPMMLsimplePredicateStrEmpty(char *field,char *operator, char *value, struct mssFPW *fpw);
void mssPMMLsimpleSetPredicateStart(char *field,char *booleanOperator, struct mssFPW *fpw);
void mssPMMLsimpleSetPredicateEnd(struct mssFPW *fpw);

#endif /* _MSSPMML_H */

==> musashi-core-2.0.1.tar.gz: musashi-core-2.0.1/lib/include/musashi/mssPMML.h <==
/**
 * # CHAPTER #
 * ============================================================================
 * PMML関連のヘッダーファイル
 * ============================================================================
 */

#ifndef __MSSPMML_H
#define __MSSPMML_H 1

/**
 * # STRUCT #
 * MUSASHIがPMML出力時に利用するグローバル変数構造体(mssPMML.cにて定義)
 */
struct mssPMMLvariables {
  int indentLevel; /*現在のインデントのレベル*/
  int outRetCnt; /*出力した改行数*/
};

/**
 * # PROTOTYPE # 
 */
void mssPMMLinit(void);
void mssPMMLindent(struct mssFPW *fpw);

void mssPMMLextensionStart( char *extender, char *name, char *value, int   emptyFlg, struct mssFPW *fpw);
void mssPMMLextensionEnd(struct mssFPW *fpw);
void mssPMMLarrayStr(int *n, char **str, struct mssFPW *fpw);
void mssPMMLfalseEmpty(struct mssFPW *fpw);
void mssPMMLtrueEmpty(struct mssFPW *fpw);

void mssPMMLpmmlStart( char *version, struct mssFPW *fpw);
void mssPMMLpmmlEnd(struct mssFPW *fpw);

void mssPMMLheaderStart(char *copyright, char *description, struct mssFPW *fpw);
void mssPMMLheaderEnd(struct mssFPW *fpw);
void mssPMMLapplicationEmpty( char *name, char *version, struct mssFPW *fpw);
void mssPMMLtimestamp(struct mssFPW *fpw);

void mssPMMLdataDictionaryStart( int *numberOfFields, struct mssFPW *fpw);
void mssPMMLdataDictionaryEnd(struct mssFPW *fpw);
void mssPMMLdataFieldStart(char *name, char *displayName, char *optype, char *taxonomy, int  *isCyclic, int emptyFlg, struct mssFPW *fpw);
void mssPMMLdataFieldEnd(struct mssFPW *fpw);
void mssPMMLvalueStart( char *value, char *displayValue, char *property, int emptyFlg, struct mssFPW *fpw);
void mssPMMLvalueEnd(struct mssFPW *fpw);


void mssPMMLminingSchemaStart(struct mssFPW *fpw);
void mssPMMLminingSchemaEnd(struct mssFPW *fpw);
void mssPMMLminingFieldStart(char *name, char *usageType, char *outliers, double *lowValue, double *highValue, char *missingValueReplacement, char *missingValueTreatment, int emptyFlg, struct mssFPW *fpw);
void mssPMMLminingFieldEnd(struct mssFPW *fpw);
void mssPMMLminingFields( struct mssFields *fld, char *usageType, char *outliers, double *lowValue, double *highValue, char *missingValueReplacement, char *missingValueTreatment, struct mssFPW *fpw);
void mssPMMLtreeModelStart( char *modelName, char *functionName, char *algorithmName, char *splitCharacteristic, struct mssFPW *fpw);
void mssPMMLtreeModelEnd(struct mssFPW *fpw);
void mssPMMLnodeStart( char *score, double *recordCount, struct mssFPW *fpw);
void mssPMMLnodeEnd(struct mssFPW *fpw);
void mssPMMLsimplePredicateNumEmpty(char *field,char *operator, double *value, struct mssFPW *fpw);
void mssPMMLsimplePredicateStrEmpty(char *field,char *operator, char *value, struct mssFPW *fpw);
void mssPMMLsimpleSetPredicateStart(char *field,char *booleanOperator, struct mssFPW *fpw);
void mssPMMLsimpleSetPredicateEnd(struct mssFPW *fpw);

#endif /* _MSSPMML_H */
